// Copyright 2015 The Go Authors. All rights reserved.
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

package mips

var cnames0 = []string{
	"NONE",
	"REG",
	"FREG",
	"FCREG",
	"MREG",
	"HI",
	"LO",
	"ZCON",
	"SCON",
	"UCON",
	"ADD0CON",
	"AND0CON",
	"ADDCON",
	"ANDCON",
	"LCON",
	"DCON",
	"SACON",
	"SECON",
	"LACON",
	"LECON",
	"DACON",
	"STCON",
	"SBRA",
	"LBRA",
	"SAUTO",
	"LAUTO",
	"SEXT",
	"LEXT",
	"ZOREG",
	"SOREG",
	"LOREG",
	"GOK",
	"ADDR",
	"TLS",
	"TEXTSIZE",
	"NCLASS",
}
